document.getElementById("searchForm").addEventListener("submit", function (e) {
  e.preventDefault();
  const brandName = document.getElementById("brandName").value.trim();
  const resultsDiv = document.getElementById("results");

  if (brandName) {
    // Show loading state
    resultsDiv.innerHTML = `<p class="loading">Searching for "${brandName}"...</p>`;

    // Fetch results from DuckDuckGo API
    fetch(
      `https://api.duckduckgo.com/?q=${encodeURIComponent(brandName)}&format=json&no_html=1`,
    )
      .then((response) => response.json())
      .then((data) => {
        if (data.AbstractText) {
          // Display results
          resultsDiv.innerHTML = `
            <div class="result-item">
              <p><strong>Results for "${brandName}":</strong></p>
              <p>${data.AbstractText}</p>
              ${data.Heading ? `<p><em>Source: ${data.Heading}</em></p>` : ""}
              ${data.Image ? `<img src="${data.Image}" alt="${data.Heading}" style="max-width: 100%; margin-top: 1rem;">` : ""}
            </div>
          `;
        } else {
          // No results found
          resultsDiv.innerHTML = `<p class="error">No results found for "${brandName}".</p>`;
        }
      })
      .catch((error) => {
        console.error("Error:", error);
        resultsDiv.innerHTML = `<p class="error">An error occurred while searching. Please try again later.</p>`;
      });
  } else {
    // No input provided
    resultsDiv.innerHTML = `<p class="error">Please enter a brand name.</p>`;
  }
});
